import Qt 4.7


Flipable {
    id: container
    property alias image: backImage.source
    property bool flipped: false
//    property real xAxis: 1
//    property real yAxis: 0

    width: 74
    height: 74

    state: "away"

    front: Rectangle {
        id: front
        width: container.width
        height: container.height
        radius: 7
        gradient: Gradient {
            GradientStop { position: 0.0; color: "#3E3E3E" }
            GradientStop { position: 1.0; color: "black" }
        }

        smooth: true
        Text {
            color: "white"
            text: "?"
            anchors.centerIn: parent
        }
    }

    back: Rectangle {
        id: back
        width: front.width
        height: front.height
        radius: front.radius
        color: "white"
        smooth: front.smooth

        Image {
            id: backImage
            anchors.centerIn: parent
            width: back.width - back.radius
            height: back.width - back.radius
            sourceSize: width + "x" + height
        }
    }

    MouseArea {
        anchors.fill: parent
//        onClicked: container.flipped = !container.flipped
        onClicked: game.cardClicked(parent)
    }

    transform: [
        Rotation {
            id: baseRotation
            origin.x: container.width / 2
            origin.y: container.height / 2
            axis.x: 0
            axis.y: 0
            axis.z: 1
            angle: randomAngle()
        },
        Rotation {
            id: flipRotation
            origin.x: container.width / 2
            origin.y: container.height / 2
            axis.x: 0
            axis.y: 1
            axis.z: 0
            angle: 0
        },

        Scale {
            id: scale
            origin.x: container.width / 2
            origin.y: container.height / 2
        },
        Translate {
            id: translate
        }

    ]


    states: [
        State {
            name: "normal"; when: game.running && !container.flipped
        },
        State {
            name: "opened"; when: game.running && container.flipped
            PropertyChanges { target: flipRotation; angle: 180 }
        },
        State {
            name: "away"; when: !game.running
            PropertyChanges {
                target: scale
                xScale: 0
                yScale: 0
            }
            PropertyChanges {
                target: flipRotation
                angle: 700
                axis.x: 1
                axis.y: 1
                axis.z: 1
            }
            PropertyChanges {
                target: translate
                x: randomPosition();
                y: randomPosition();
            }

        }
    ]

    transitions: [
        Transition {
            from: "normal"
            to: "opened"
            NumberAnimation { target: flipRotation; property: "angle"; duration: 700 }
            SequentialAnimation {
                NumberAnimation { target: container; property: "scale"; to: 1.5; duration: 350 }
                NumberAnimation { target: container; property: "scale"; to: 1.0; duration: 350 }
            }
        },
        Transition {
            from: "opened"
            to: "normal"
            NumberAnimation { target: flipRotation; property: "angle"; duration: 700 }
            SequentialAnimation {
                NumberAnimation { target: container; property: "scale"; to: 1.5; duration: 350 }
                NumberAnimation { target: container; property: "scale"; to: 1.0; duration: 350 }
            }
        },
        Transition {
            id: awayTransition
            from: "*"
            to: "away"
            property int duration: Math.random() * 3000;

            NumberAnimation { target: flipRotation; property: "angle"; duration: awayTransition.duration }
            NumberAnimation { target: scale; property: "xScale"; duration: awayTransition.duration }
            NumberAnimation { target: scale; property: "yScale"; duration: awayTransition.duration }
            NumberAnimation { target: translate; property: "x"; to: randomPosition(); duration: awayTransition.duration }
            NumberAnimation { target: translate; property: "y"; to: randomPosition(); duration: awayTransition.duration }
        },
        Transition {
            id: startTransition
            from: "away"
            to: "normal"
            property int duration: 2000
            NumberAnimation { target: flipRotation; property: "angle"; duration: 1 }
            NumberAnimation { target: scale; property: "xScale"; duration: startTransition.duration }
            NumberAnimation { target: scale; property: "yScale"; duration: startTransition.duration }
            NumberAnimation { target: translate; property: "x"; to: 0; duration: startTransition.duration }
            NumberAnimation { target: translate; property: "y"; to: 0; duration: startTransition.duration }
        }

    ]

    function randomPosition() {
        var rand = Math.random() * 1000;
        rand = rand - 500;
        return rand;
    }

    function randomAngle() {
        var rand = Math.random() * 15;
        return rand - 7;
    }


}

