import Qt 4.7
import "logic.js" as Logic


Item {
    id: game
    property int fails: 0
    property int cardCount: imageGrid.rows * imageGrid.columns
    property bool running: false

    width: 360
    height: 360

    Image {
        id: background
        source: "images/background.png"
        //sourceSize: parent.height + "x" + parent.width
        width: parent.height;
        height: parent.width;
        x: 0
        y: -parent.width;
        rotation: 90;
        transformOrigin: Item.BottomLeft

    }

    AboutPage {
        id: aboutPage
        anchors.fill: parent
        visible: false
    }

    HelpPage {
        id: helpPage
        anchors.fill: parent
        visible: false
    }

    StatusBar {
        id: statusBar
        NumberAnimation { id: statusBarAnim; target: statusBar; property: "x"; to: 0; duration: 500 }

    }

    Grid {
        id: imageGrid
        columns: 5
        rows: 8
        spacing: 4
        anchors.bottom: game.bottom
        anchors.bottomMargin: 20
        anchors.horizontalCenter: game.horizontalCenter

        Repeater {
            model: imageGrid.columns * imageGrid.rows
            delegate: MemImage { }
        }

    }

    ScorePanel {
        id: scorePanel
    }

    Timer {
        id: startTimer
        interval: 500
        onTriggered: { Logic.showMainPanel() }
    }

    Timer {
        id: flipBackTimer
        interval: 3000
        onTriggered: { Logic.returnFlippedCards() }
    }

    Timer {
        id: endGameTimer
        interval: 2000
        onTriggered: { game.running = false; scorePanelTimer.start(); }
    }

    Timer {
        id: scorePanelTimer
        interval: 3000
        onTriggered: { scorePanel.state = "" }
    }

    Component.onCompleted: { startTimer.start() }

//    Component.onCompleted: { Logic.showAbout() }

//    Component.onCompleted: { Logic.startNewGame() }

    function cardClicked(card) {
        Logic.cardClicked(card);
    }

    function startNewGame() {
        Logic.startNewGame();
    }

    function abandonGame() {
        Logic.abandonGame();
    }

    function exit() {
        Qt.quit();
    }

    function showAbout() {
        Logic.showAbout();
    }

    function showHelp() {
        Logic.showHelp();
    }

    function closeAbout() {
        Logic.showMainPanel();
    }

    function closeHelp()
    {
        Logic.showMainPanel();
    }




}
